(function( blocks, element, editor, components, i18n ) {

	const { registerBlockType } = blocks;
	const { RichText } = editor;
	const { createElement } = element;
	const { InspectorControls } = editor;
	const { SelectControl, ToggleControl } = components;
	const { __ } = i18n;

	function hashCode(str) {
		var hash = 0, i, chr;
		if (!str || str.length === 0)
			return hash;
		for (i = 0; i < str.length; i++) {
			chr  = str.charCodeAt(i);
			hash = ((hash << 5) - hash) + chr;
			hash |= 0;
		}
		return hash;
	}

	registerBlockType( 'meowapps/faq', {
		title: __( 'FAQ', 'faq-block' ),
		icon: 'welcome-learn-more',
		category: 'formatting', // (common, formatting, layout, widgets, embed)
		keywords: [ __( 'section' ), __( 'header' ) ],
		customClassName: false,
		className: false,
		attributes: {
			question: {
				source: 'children',
				selector: '.meow-faq-question',
				default: 'Question...'
			},
			answer: {
				source: 'children',
				selector: '.meow-tab-content',
				default: 'Answer...'
			},
			hash: {
				source: 'attribute',
				attribute: 'id',
				selector: 'input',
				default: ''
			}
		},

		save: function( props ) {
			const question = props.attributes.question;
			const answer = props.attributes.answer;
			const hash = props.attributes.hash;
			const container = createElement(
				'div', { className: 'meow-faq-block' },
				React.createElement('input', { id: hash, name: hash, type: 'checkbox' }),
				createElement( RichText.Content, { tagName: 'label', className: 'meow-faq-question', value: question, htmlFor: hash }),
				React.createElement('div', { className: 'meow-tab-answer' },
					createElement( RichText.Content, { tagName: 'div', className: 'meow-tab-content', value: answer })
				)
			);
			return container;
		},

		edit: function( props ) {
			const question = props.attributes.question;
			const answer = props.attributes.answer;
			const focus = props.focus;

			function onChangeQuestion( newContent ) {
				props.setAttributes( { question: newContent } );
				props.setAttributes( { hash: Math.random().toString(36).substr(2, 9) } );
			}

			function onChangeAnswer( newContent ) {
				props.setAttributes( { answer: newContent } );
			}

			const editQuestion = createElement(
				RichText,
				{
					tagName: 'h3',
					onChange: onChangeQuestion,
					value: question,
					focus: focus,
					onFocus: props.setFocus,
				}
			);
			const editAnswer = createElement(
				RichText,
				{
					tagName: 'p',
					onChange: onChangeAnswer,
					value: answer,
					focus: focus,
					onFocus: props.setFocus,
				}
			);
			return createElement(
				'div', { key: 'meow-faq-block-div', className: 'meow-faq-block' },
				//React.createElement('input', { id: 'meow-faq-block', name: 'meow-faq-block', type: 'checkbox' }),
				editQuestion,
				editAnswer
			);
		},

	});

})(
	window.wp.blocks,
	window.wp.element,
	window.wp.editor,
	window.wp.components,
	window.wp.i18n
);
